/* resources/css/filament.css */

/* Contoh: Mengubah warna background header */
.fi-topbar {
    background-color: #333 !important; /* Warna gelap */
}

/* Contoh: Mengubah warna background sidebar */
.fi-sidebar {
    background-color: #222 !important; /* Warna yang lebih gelap */
}

/* Contoh: Mengubah warna teks navigasi di sidebar */
.fi-sidebar .fi-sidebar-item-label {
    color: #eee !important;
}

/* Contoh: Mengubah warna background item navigasi aktif di sidebar */
.fi-sidebar .fi-sidebar-item.fi-active {
    background-color: #444 !important;
}